@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 63 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 67 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 76 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 92 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 156 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 159 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 161 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -162,19 +162,19 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 174 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 174 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", false);
-//@line 178 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 178 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 198 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 198 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 201 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 201 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -518,9 +518,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 545 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 545 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 547 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 547 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -569,9 +569,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 596 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 596 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 598 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 598 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -707,6 +707,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -715,6 +716,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -725,6 +727,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -733,6 +736,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -740,6 +745,11 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
 pref("network.IDN.whitelist.xn--p1ai", true);
 // sa, Saudi Arabia, .<al-Saudiah> with variants
@@ -747,11 +757,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -837,7 +850,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 869 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 882 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1258,18 +1271,18 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1687 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1700 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1689 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1702 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
 pref("ui.click_hold_context_menus", false);
 
-//@line 1695 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1708 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 // whether to always use ATSUI for text even if CoreText is available
 pref("gfx.force_atsui_text", false);
-//@line 1698 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1711 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // default fonts (in UTF8 and using canonical names)
 // to determine canonical font names, use a debug build and 
@@ -1681,21 +1694,21 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2111 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2124 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2314 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2327 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2410 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2423 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2685 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2698 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2753 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2766 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2792 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2799 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2812 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2807 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2820 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1732,9 +1745,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2849 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2862 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2854 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2867 "/builds/slave/m-192-osx-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
